
/*This file contains the codes for Po-Hsuan Hsu, Hao Liang, and Pedro Matos "Leviathan Inc. and Corporate Environmental Engagement" accepted for publication at Management Science*/

clear all
set matsize 11000

/******************************************************************************/
/*Table 1: Forbes 30 firms 2010 only*/

use forbes30, clear 

tabstat GUO_state3 /*government_held*/ ENVSCORE ENER ENPI ENRR SOCSCORE CGVSCORE if forbes_top30==1 & year==2010, by(forbes_rank) stat(mean) 
export excel using table1.xls


/****************************************/
/*Preparation  ***************************/

/*We combine 2 datasets: the public one "data_for_public_MS" and the proprietary one "data_proprietary_MS"*/
use data_for_public_MS, clear 


// we then merge variables from the dataset "data_proprietary_MS" to the dataset "data_for_public_MS"  

so ds1 year
merge 1:1 ds1 year using data_proprietary_MS

drop if _m==2
drop _m
xtset ds1 year
so ds1 year

g log_mktcap =log(mktcap)

/*winsorize variables by whole sample*/
foreach var in log_mktcap leverage MTBV2 lngdppc io roa hhi48_ctry {  
    winsor `var', gen(`var'_w05a) p(0.05) 
  }

tabulate country_id, generate(country_)
tabulate year_id, generate(year_)
tabulate indm_id, generate(industry_)
	 

g industry_yr_id = indm_id*10000+year_id
g country_yr_id = country_id*10000+year_id

g trbc_id_country = trbc_id*100+country_id 
g trbc_country_yr_id = trbc_id*1000000+country_id*10000 +year
 
g indm_id_country = indm_id*100+country_id 
g indm_country_yr_id = indm_id*1000000+country_id*10000 +year

 
 
g firm_yr_id = firm_id*1000+year

xtset ds1 year
so ds1 year

g l_io=l.io
g l_leverage=l.leverage
g l_MTBV2=l.MTBV2
g l_roa=l.roa
g l_log_mktcap=l.log_mktcap
g l_hhi48_ctry=l.hhi48_ctry
g l_CGVSCORE = l.CGVSCORE
g l_GUO_state3 = l.GUO_state3


g l_io_w05a=l.io_w05a
g l_log_mktcap_w05a=l.log_mktcap_w05a
g l_leverage_w05a=l.leverage_w05a
g l_MTBV2_w05a=l.MTBV2_w05a
g l_roa_w05a=l.roa_w05a

g ENVSCORE_d1= ENVSCORE - l.ENVSCORE
g ENER_d1= ENER - l.ENER
g ENPI_d1= ENPI - l.ENPI
g ENRR_d1= ENRR - l.ENRR


g l_gov1_01a = l.gov1_01a
g l_gov1_10a = l.gov1_10a
 
foreach var in ln_total_co2_a   {  
    winsor `var', gen(`var'_w01a) p(0.01) 
  } 


/*impose this for sample consistency*/
gen sample1=0
replace sample1=1 if (ENVSCORE~=. & l.GUO_state3~=. & l.io_w05a ~=. & l.log_mktcap_w05a~=. & l.leverage_w05a~=. & l.MTBV2_w05a~=. & l.roa_w05a~=. & lngdppc~=. & hhi48_ctry~=. & CGVSCORE ~= .)


/*for summary statistics - to generate gg, an indicator for main regression sample*/
foreach x of varlist GUO_state3 {
foreach y of varlist ENVSCORE {
estimate clear
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
 	reghdfe `y' l.`x' `controls4' if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	  
	gen gg = 1 if  e(sample) == 1
	est clear
}
}   
 
 
/******************************************************************************/
/*Univariate test - Table 2 Panel A *******************************************/
/*THE TOP ROW FOR all*/
sum l_GUO_state3 if gg==1
sum ENVSCORE if gg==1
ttest ENVSCORE if gg==1 , by(l_GUO_state3) unequal
sum ENER if gg==1
sum ENPI if gg==1
sum ENRR if gg==1
sum SOCSCORE if gg==1
sum CGVSCORE if gg==1


/*Country-level statistics*/
table country if gg==1, c(n ENVSCORE)  col row 
table country if gg==1, c(mean GUO_state3 mean ENVSCORE mean ENER mean ENPI mean ENRR )  col row  
table country if gg==1, c(mean SOCSCORE mean CGVSCORE )  col row  

/*ENVSCORE: SOEs vs. others for Table 2*/ 
ttest ENVSCORE if gg==1 & country == "AT", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "AU", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "BE", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "BR", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "CA", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "CH", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "CL", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "CN", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "CO", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "CZ", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "DE", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "DK", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "EG", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "ES", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "FI", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "FR", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "GB", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "GR", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "HK", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "HU", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "ID", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "IE", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "IL", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "IN", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "IT", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "JP", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "KR", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "MA", by(GUO_state3) unequal
/*ttest ENVSCORE if gg==1 & country == "MX", by(GUO_state3) unequal*/
ttest ENVSCORE if gg==1 & country == "MY", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "NL", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "NO", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "NZ", by(GUO_state3) unequal
/*ttest ENVSCORE if gg==1 & country == "PE", by(GUO_state3) unequal*/
ttest ENVSCORE if gg==1 & country == "PH", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "PL", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "PT", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "RU", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "SE", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "SG", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "TH", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "TR", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "US", by(GUO_state3) unequal
ttest ENVSCORE if gg==1 & country == "ZA", by(GUO_state3) unequal
 

/* Table 2 Panel B */
/*each Industry*/  
replace icbin = "Others" if icbin == "" & trbc_id != .
table icbin if gg==1, c(n ENVSCORE mean GUO_state3 mean ENVSCORE )  col row 
table icbin if gg==1, c(mean SOCSCORE mean CGVSCORE)  col row 
 /*compare GUO_state = 1 to 0*/
/*table icbin if gg==1 & GUO_state == 1, c(mean ENVSCORE )  col row 
table icbin if gg==1 & GUO_state == 0, c(mean ENVSCORE )  col row */
/*ENVSCORE*/ 
ttest ENVSCORE if gg==1  & icbin == "Basic Materials", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Consumer Goods", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Consumer Services", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Financials", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Health Care", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Industrials", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Oil & Gas", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Technology", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Telecommunications", by( GUO_state3 )
ttest ENVSCORE if gg==1  & icbin == "Utilities", by( GUO_state3 ) 
 
/******************************************************************************/
/* Table 3 Panel A */ 
asdoc sum ENVSCORE ENER ENPI ENRR SOCSCORE CGVSCORE ln_total_co2_a_w01a l_GUO_state3 l_io_w05a l_log_mktcap_w05a l_leverage_w05a l_MTBV2_w05a l_roa_w05a lngdppc hhi48_ctry waste_sic2_med2 l_mean_ab_temp_abs_hi l_mean_pdsi_hi l_gov1_01a l_gov1_10a energy_dependence energy_dependence_hi mktcap_gdp mktcap_gdp_hi E_regulation_hi foreign_assets foreign_sales  foreign_income_growth  retirement_age1 Tenure PoliticalConnection government_held3a foreign_holdings cross_holdings pension_fund_held investment_co_held employee_held  strategic_holdings io_dom io_for foreign_state swf /*msci*/ /*sustanaltics*/ if gg ==1, stat(N mean sd min p25 p50 p75 max  )


/* Table 3 Panel B */
corr l_GUO_state3 government_held3a ENVSCORE ENER ENPI ENRR SOCSCORE CGVSCORE /// 
	l_io_w05a l_log_mktcap_w05a l_leverage_w05a l_MTBV2_w05a l_roa_w05a lngdppc hhi48_ctry if gg ==1
	
pwcorr l_GUO_state3 government_held3a ENVSCORE ENER ENPI ENRR SOCSCORE CGVSCORE /// 
	l_io_w05a l_log_mktcap_w05a l_leverage_w05a l_MTBV2_w05a l_roa_w05a lngdppc hhi48_ctry if gg ==1, sig
	

/******************************************************************************/

/* Table 4 Panel A */
foreach x of varlist GUO_state3 {
foreach y of varlist ENVSCORE ENER ENPI ENRR ln_total_co2_a_w01a  {
estimate clear
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
 	reghdfe `y' l.`x'   if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table4-panel-a.xls, append ctitle (`y') keep(`y' l.`x' `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)
	
 	reghdfe `y' l.`x'  `controls4' /*CGVSCORE*/ if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table4-panel-a.xls, append ctitle (`y') keep(`y' l.`x' `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)	
	est clear
}
}  


/* Table 4 Panel B */

gen GUO_state3_lag5 = GUO_state if year < 2005 & year != .
so firm_id year
by firm_id (year): carryforward GUO_state3_lag5, replace


local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
local period "year >= 2004 & year <= 2017"

xtset firm_id year
/* Column (1)*/	
 	reghdfe ENVSCORE GUO_state3_lag5 `controls4'  if sample1==1 & year >= 2009, a(trbc_id_yr  country_id) vce(cl firm_id)
	outreg2 using table4-panel-b.xls, append ctitle (ENVSCORE) keep(GUO_state3_lag5 `controls4') addtext(TRBC-YR FE, Yes, TRBC FE, No, Country FE, Yes, Sample, Post 2009)

/* Column (2)*/	
	reghdfe ENVSCORE l5.GUO_state3 `controls4' if sample1==1 & year >= 2009, a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table4-panel-b.xls, append ctitle (ENVSCORE) keep(l5.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, TRBC FE, No, Country FE, Yes, Sample, Post 2009)

/* Column (3)*/
 	reghdfe ENVSCORE l5.GUO_state3 `controls4' if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table4-panel-b.xls, append ctitle (ENVSCORE) keep(l5.GUO_state3 `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, TRBC FE, No, Country FE, Yes, Sample, Full)

/* Column (4)*/
xtset firm_id year
by firm_id: egen GUO_state3_pre09 = mean(GUO_state3) if year < 2009 & year != .
by firm_id (year): carryforward GUO_state3_pre09, replace

foreach x in ENVSCORE io_w05a log_mktcap_w05a leverage_w05a MTBV2_w05a roa_w05a lngdppc hhi48_ctry {
by firm_id: egen `x'_post09 = mean(`x') if year >= 2009 & year != .
}

preserve
collapse ENVSCORE_post09 GUO_state3_pre09 io_w05a_post09 log_mktcap_w05a_post09 leverage_w05a_post09 MTBV2_w05a_post09 roa_w05a_post09 lngdppc_post09 hhi48_ctry_post09 sample trbc_id country_id , by(firm_id)



	local controls4 "io_w05a_post09 log_mktcap_w05a_post09 leverage_w05a_post09 MTBV2_w05a_post09 roa_w05a_post09 lngdppc_post09 hhi48_ctry_post09 "

	reghdfe ENVSCORE_post09 i.country_id GUO_state3_pre09 `controls4' , a(trbc_id ) vce(cl firm_id)
	outreg2 using table4-panel-b.xls, append ctitle (ENVSCORE_post09) keep(GUO_state3_pre09 `controls4') addtext(TRBC-YR FE, No, TRBC FE, Yes, Country FE, Yes, Sample, Collapsed)
	    
restore


/******************************************************************************/


/* Table 5 Panel A */

g post_2011 = 1 if year> 2011
replace post_2011 = 0 if post_2011 != 1

replace trbc_code = "" if trbc_code == "NA"
destring trbc_code, replace

gen utility=0
replace utility=1 if trbc_code==	50103010
replace utility=1 if trbc_code==	59101010
replace utility=1 if trbc_code==	59101020
replace utility=1 if trbc_code==	50102010
replace utility=1 if trbc_code==	59104010
replace utility=1 if trbc_code==	59102010
replace utility=1 if trbc_code==	50102020
replace utility=1 if trbc_code==	50102030
replace utility=1 if trbc_code==	50103030
replace utility=1 if trbc_code==	50103020
replace utility=1 if trbc_code==	50201010
replace utility=1 if trbc_code==	50201020
replace utility=1 if trbc_code==	59103010


gen nuclear_heavy = 1 if country == "CA" | country == "CN" | country == "FR" | country == "IN" | country == "JP" | ///
						country == "KR" | country == "GB" | country == "US"
replace nuclear_heavy = 0 if nuclear_heavy != 1


	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry"
	local period "year >= 2009 & year <= 2014"

	
	
/*Column (1)*/
	reghdfe ENVSCORE i.l.GUO_state3##i.post_2011 /*`controls4'*/ if sample1==1 & `period' , a(trbc_id_yr country_id ) vce(cl firm_id)
	outreg2 using table5-panel-a.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##i.post_2011 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Full)

/*Column (2)*/	
    reghdfe ENVSCORE i.l.GUO_state3##i.post_2011##i.utility `controls4' CGVSCORE if sample1==1 & `period' , a(trbc_id_yr country_id ) vce(cl firm_id)				
	outreg2 using table5-panel-a.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##i.post_2011##i.utility `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Full)

/*Column (3)*/		
	reghdfe ENVSCORE i.l.GUO_state3##i.post_2011##i.utility `controls4' CGVSCORE if sample1==1 & `period' & nuclear_heavy==1, a(trbc_id_yr country_id ) vce(cl firm_id)	
	outreg2 using table5-panel-a.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##i.post_2011##i.utility `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Nuclear-Heavy)

/*Column (4)*/	
	reghdfe ENVSCORE i.l.GUO_state3##i.post_2011##i.utility `controls4' CGVSCORE if sample1==1 & `period' & nuclear_heavy==0, a(trbc_id_yr country_id ) vce(cl firm_id)	
	outreg2 using table5-panel-a.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##i.post_2011##i.utility `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Nuclear-Light)



/* Table 5 Panel B */
xi i.icbin
gen _Iicbin_1 = 1 if icbin_id == 1
replace _Iicbin_1 = 0 if _Iicbin_1 != 1
** _Iicbin_7 is NA; _Iicbin_11 is Utilities**

foreach z of varlist _Iicbin_1 _Iicbin_2 _Iicbin_3 _Iicbin_4 _Iicbin_5 _Iicbin_6 /*_Iicbin_7*/ _Iicbin_8 _Iicbin_9 _Iicbin_10 /*_Iicbin_11*/ {

estimate clear

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry"
	local period "year >= 2009 & year <= 2014"

	reghdfe ENVSCORE i.l.GUO_state3##i.post_2011##i.`z' `controls4' if sample1==1 & `period', a(trbc_id_yr country_id ) vce(cl firm_id)
    outreg2 using table5-panel-b.xls, append ctitle (`y') keep(i.l.GUO_state3##i.post_2011##i.`z' `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2009-2014)
}



/*Table 5 Panel C*/

foreach z of varlist mean_ab_temp_abs_hi mean_pdsi_hi  {
    
estimate clear

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
 		local period "year >= 2004 & year <= 2017"	
		
	reghdfe ENVSCORE i.l.GUO_state3##c.l.waste_sic2_med2##c.l.`z' `controls4'  if sample1==1 & `period' , a(trbc_id_yr country_id ) vce(cl firm_id)
	outreg2 using table5-panel-c.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##c.l.waste_sic2_med2##c.l.`z' `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes)		

	est clear
}


/******************************************************************************/
/* Table 6 */

/*Columns (1) and (2)*/

foreach z of varlist gov1_01a gov1_10a   {
estimate clear

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE_d1 i.l.GUO_state3##i.l.`z' `controls4' if sample1==1 & `period' , a(trbc_id_yr country_id) vce(cl firm_id)
	outreg2 using table6.xls, append ctitle (ENVSCORE_d1) keep(i.l.GUO_state3##i.l.`z' `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes)	
	
est clear
}

/*Column (3)*/

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE_d1 i.l.GUO_state3##i.l.gov1_01a i.l.GUO_state3##i.l.gov1_10a `controls4' if sample1==1 & `period' , a(trbc_id_yr country_id) vce(cl firm_id)
	outreg2 using table6.xls, append ctitle (ENVSCORE_d1) keep(i.l.GUO_state3##i.l.gov1_01a i.l.GUO_state3##i.l.gov1_10a `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes)	


/*Column (4)*/

by firm_id (year): gen new_stateown = 1 if government_held[_n-1] < 25 & government_held - government_held[_n-1] > 25 & !missing(government_held) & !missing(government_held[_n-1])
gen last = year if new_stateown == 1
by firm_id (year): carryforward last, replace

by firm_id (year): carryforward new_stateown if (year - last) < 4 & !missing(year - last), replace
replace new_stateown = 0 if new_stateown != 1 & !missing(GUO_state) 

gen old_stateown = 0
replace old_stateown = 1 if government_held >= 25 & !missing(government_held)
replace old_stateown = 0 if new_stateown == 1

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
			
	reghdfe ENVSCORE_d1 old_stateown new_stateown `controls4' CGVSCORE, a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table6.xls, append ctitle (ENVSCORE_d1) keep(old_stateown new_stateown `controls4' CGVSCORE) addtext(TRBC-YR FE, Yes, Country FE, Yes)



/******************************************************************************/
/* Table 7 */

/*Column (1)*/
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE i.l.GUO_state3##c.CGVSCORE `controls4' if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table7.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##c.CGVSCORE `controls4' ) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)

/*Columns (2) to (7)*/

foreach z of varlist vae pve gee rqe rle cce {
estimate clear

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE i.l.GUO_state3##c.`z' CGVSCORE `controls4' if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table7.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##c.`z' CGVSCORE `controls4' ) addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)


	est clear
}


/******************************************************************************/
/* Table 8 Panel A */
foreach var in foreign_assets foreign_sales foreign_income_growth {

winsor `var', gen(`var'_w05a) p(0.05)
}
				
foreach z of varlist foreign_assets_w05a foreign_sales_w05a foreign_income_growth_w05a {

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"

	reghdfe ENVSCORE i.l.GUO_state3##c.l.`z' `controls4' if sample1==1 & `period', a(trbc_id_yr country_id ) vce(cl firm_id)
	outreg2 using table8-panel-a.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##c.l.`z' `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes)	


estimate clear
}


/* Table 8 Panel B */
foreach z of varlist retirement_age1 Tenure l.PoliticalConnection {

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"

	reghdfe ENVSCORE c.l.GUO_state3##c.`z' `controls4' if sample1==1 &`period', a(trbc_id_yr country_id ) vce(cl firm_id)
	outreg2 using table8-panel-b.xls, append ctitle (ENVSCORE) keep(c.l.GUO_state3##c.`z' `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes)		


estimate clear
}

/******************************************************************************/
/* Table 9 */
/* energy_dependence_hi and E_regulaton_hi are already generated in the dataset 
egen energy_dependence_median = median(energy_dependence)
gen energy_dependence_hi = 1 if energy_dependence > energy_dependence_median & energy_dependence != . & energy_dependence_median
replace energy_dependence_hi = 0 if energy_dependence <= energy_dependence_median & energy_dependence != .


gen E_regulation_hi = 1 if E_regulation != 0 & E_regulation != .
replace E_regulation_hi = 0 if E_regulation == 0 
*/


foreach z of varlist energy_dependence E_regulation {
estimate clear

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"

	reghdfe ENVSCORE l.GUO_state3 `controls4' if sample1==1 & `period' & `z'_hi == 1, a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table9.xls, append ctitle (ENVSCORE) keep(l.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017 High `z')	

	reghdfe ENVSCORE l.GUO_state3 `controls4' if sample1==1 & `period' & `z'_hi == 0, a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table9.xls, append ctitle (ENVSCORE) keep(l.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017 Low `z')	

	est clear
}
//

/******************************************************************************/
/* Table 10 Panel A */

foreach x of varlist government_held3a foreign_holdings cross_holdings pension_fund_held investment_co_held employee_held  strategic_holdings io_dom io_for {

estimate clear

	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"

	reghdfe ENVSCORE l.`x' `controls4' CGVSCORE if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table10-panel-a.xls, append ctitle (ENVSCORE) keep(l.`x' `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)

	est clear
}
//  

/* Table 10 Panel B */
* our sample expanded from the initial version ending in 2014 to the published version ending in 2017 *
foreach x in foreign_state foreign_swf foreign_GUO domestic_state_held domestic_swf domestic_GUO {
replace `x' = l.`x' if `x' == . & year == 2015
replace `x' = l2.`x' if `x' == . & year == 2016
replace `x' = l3.`x' if `x' == . & year == 2017
}

foreach x of varlist foreign_state foreign_swf foreign_GUO domestic_state_held domestic_swf domestic_GUO {
bys firm_id (year): carryforward `x', replace

}

foreach x of varlist foreign_state foreign_swf foreign_GUO domestic_state_held domestic_swf domestic_GUO {
gsort firm_id - year
bysort firm_id: carryforward `x', replace
}

sort firm_id year

	
	
/*column (1)*/
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE l.GUO_state3 `controls4' if foreign_GUO == 1 & `period', a(trbc_id_yr country_id) vce(cl firm_id)
    outreg2 using table10-panel-b.xls, append ctitle (ENVSCORE) keep(l.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Foreign GUO)

/*column (2)*/
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE l.GUO_state3 `controls4' if foreign_GUO == 0 & `period', a(trbc_id_yr country_id) vce(cl firm_id)
    outreg2 using table10-panel-b.xls, append ctitle (ENVSCORE) keep(l.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Domestic GUO)
	


/*column (3)*/
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE i.l.GUO_state3##i.foreign_state `controls4' if `period', a(trbc_id_yr country_id) vce(cl firm_id)
	outreg2 using table10-panel-b.xls, append ctitle (ENVSCORE) keep(i.l.GUO_state3##i.foreign_state `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Full)

/*column (4)*/
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
	reghdfe ENVSCORE l.GUO_state3 l.swf `controls4' if `period', a(trbc_id_yr country_id) vce(cl firm_id)
    outreg2 using table10-panel-b.xls, append ctitle (ENVSCORE) keep(l.GUO_state3 l.swf `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, Full)


/******************************************************************************/

/* Table 12 */

foreach y of varlist SOCSCORE CGVSCORE  {
estimate clear
	local controls4 "l.io_w05a l.log_mktcap_w05a l.leverage_w05a l.MTBV2_w05a l.roa_w05a lngdppc hhi48_ctry "
	local period "year >= 2004 & year <= 2017"
	
 	reghdfe `y' l.GUO_state3 if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table12.xls, append ctitle (`y') keep(l.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)
	
 	reghdfe `y' l.GUO_state3 `controls4' if sample1==1 & `period', a(trbc_id_yr  country_id) vce(cl firm_id)	
	outreg2 using table12.xls, append ctitle (`y') keep(l.GUO_state3 `controls4') addtext(TRBC-YR FE, Yes, Country FE, Yes, Sample, 2004-2017)
	
	est clear
}
/******************************************************************************/

/* Table 11 */

/* Note: Variables from proprietary data sources:
l_io_w05a is lagged instituoinal ownership from FactSet
l_log_mktcap_w05a  is lagged market capitalization (log-transformed) from Datastream/Worldscope
l_leverage_w05a  is lagged leverage from Datastream/Worldscope
l_MTBV2_w05a  is lagged market-to-book ratio from Datastream/Worldscope
l_roa_w05a  is lagged ROA from Datastream/Worldscope
hhi48_ctry  is HH index based on Fama-French 48 industries classification
*/
use msci_esg, clear 

	local controls4 "l_io_w05a l_log_mktcap_w05a l_leverage_w05a l_MTBV2_w05a l_roa_w05a lngdppc hhi48_ctry"
 	areg environmental_pillar_score l_GUO_state3 `controls4' i.country_id if sample1 == 1, a(industry1_id ) vce(cl industry1_id)
    outreg2 using table11.xls, append ctitle (msci_environment) keep(l_GUO_state3 `controls4') addtext(Industry-YR FE, No, Industry FE, Yes, Country FE, Yes, Model, Cross-section OLS)


use sustainalytics, clear 

	local controls4 "l_io_w05a l_log_mktcap_w05a l_leverage_w05a l_MTBV2_w05a l_roa_w05a lngdppc hhi48_ctry"
 	reghdfe environaw05 l_GUO_state3 `controls4' if sample1==1 & year >= 2004 & year <=2017 & isin_id ~= ., a(trbc_id_yr country_id) vce(cl isin_id)
    outreg2 using table11.xls, append ctitle (sustainalytics_environment) keep(l_GUO_state3 `controls4') addtext(Industry-YR FE, Yes, Industry FE, No, Country FE, Yes, Model, Pooled OLS)



/*******************************************************************************/
/* Figure 1: Emission Database for Global Atmospheric Research (EDGAR) 4.3.2, European Commission, Joint Research Centre (JRC)/PBL Netherlands Environmental Assessment Agency.**/

/*******************************************************************************/
/* Figure 2: No data involved **************************************************/

/*******************************************************************************/
/* Figures 3 & 4: see EXCEL files**/
